# Create figure 6 from
# Rothkegel, L. O. M., Trukenbrod, H. A., Schü̈tt, H. H., Wichmann, F. A., & Engbert, R. (2016).
# Influence of initial fixation position in scene viewing. Vision research, 129, 33–49. 

# Clear Workspace 
rm(list=ls())


# Set working directory to current source location

dir <- dirname(parent.frame(2)$ofile)
setwd(dir)


#Packages needed
library(spatstat)
library(ggplot2)
library(Rmisc)
library("grid")
library("gridExtra")
library(png)
library(lme4)

## read table and image boundaries and reduce table to variables needed



Table<-read.table("Fixations.dat",header=TRUE)
imrange <- read.table("Image_Range.dat",header=TRUE)


# Reduce Table to importang variables and better variable names

table<-data.frame((Table$xR+Table$xL)/2,(Table$yR+Table$yL)/2,Table$image,Table$fd,Table$nth,Table$id,Table$type,Table$fCroX)
colnames(table)<-c("xPos","yPos","Image","FixDur","Fixation_Number","Subject","type","Start")
table<-table[order(table$Image),]

rm(Table)

# Add difference of a x and y position between fixation n and n+1

trialstart<-c(which(table$Fixation_Number==1))
table$xdiff<-c(diff(table$xPos),NA)
table$ydiff<-c(diff(table$yPos),NA)
table$xdiff[trialstart-1]<-NA
table$ydiff[trialstart-1]<-NA

# Add difference of a x and y position between fixation n and n+2

table$xdiff2<-c(NA,table$xdiff[1:(length(table$xdiff)-1)])
table$ydiff2<-c(NA,table$ydiff[1:(length(table$ydiff)-1)])

# Create Points that represent Saccadic Endpoints in relation to previous saccade
V1<-((table$xdiff*table$xdiff2)+(table$ydiff*table$ydiff2))/((table$ydiff2^2+table$xdiff2^2))
V2<-((table$xdiff*-(table$ydiff2))+(table$ydiff*table$xdiff2))/((table$ydiff2^2+table$xdiff2^2))

# Compute saccadic Angle from these Points
Angle<-(atan2(V1,V2)+pi/2)*180/pi
# Transform Angle to 0-360 Degrees and create Angle dataframe for ggplot
Angle[which(Angle<0)]<-Angle[which(Angle<0)]+360
Ango<-180-(abs(Angle-180))
Angle<-Angle[!is.na(Angle)]
Angle<-data.frame(Angle)
table$Ango<-Ango


# 
# Z1<-((table$xdiff*table$xdiff2)+(table$ydiff*table$ydiff2))/(sqrt((table$ydiff2^2+table$xdiff2^2)))
# Z2<-((table$xdiff*-(table$ydiff2))+(table$ydiff*table$xdiff2))/(sqrt((table$ydiff2^2+table$xdiff2^2)))



Fig6a<-ggplot(Angle,aes(x=Angle))+geom_histogram(colour = "black", fill = "white", binwidth = 6,center=3)+
  ylab("Frequency")+xlab("Angle [°]")+theme(axis.text = element_text(size=13),axis.title = element_text(size=20))+scale_x_continuous(breaks=c(0,90,180,280,360))
                                                                                                                                     

# Remove NA from V1
X<-which(is.na(V1))
Frame<-data.frame(V1[-X],V2[-X])
colnames(Frame)<-c("X","Y")

table$sacle<-sqrt(table$xdiff^2+table$ydiff^2)
saclePrev<-c(NA,table$sacle)
table$sacleprev<-saclePrev[-length(saclePrev)]


# Create Density Plot of Relation between two successive Saccades. 
Fig6b<-ggplot(Frame,aes(x=X,y=Y))+  xlim(c(-1.5,1.5)) + ylim(c(-1.5,1.5))+xlab("Parallel to Previous Saccade")+
    stat_density2d(aes(fill = ..level..), geom="polygon" )+ylab("Orthogonal to Previous Saccade")+ggtitle("All Saccades")+
  scale_fill_gradient2(name="Intensity",low = "blue", mid = "yellow", high =("red"), 
                       midpoint = 0.75, space = "rgb", na.value = "grey50", guide = "colourbar")+
  theme(legend.position=c(1,0),legend.justification=c(1,0),legend.title=element_text(size=20),legend.text=element_text(size=18),
        axis.text = element_text(size=20),axis.title = element_text(size=20),plot.title=element_text(size=20))+geom_point(alpha=0.1,size=1)

small<-which(table$Fixation_Number<3)
Frame2<-data.frame(V1[small],V2[small])
colnames(Frame2)<-c("X","Y")

Fig6c<-ggplot(Frame2,aes(x=X,y=Y)) + xlim(c(-1.5,1.5)) + ylim(c(-1.5,1.5))+xlab("Parallel to Previous Saccade")+
  stat_density2d(aes(fill = ..level..), geom="polygon" )+ylab("Orthogonal to Previous Saccade")+ggtitle("Second Saccade Only")+
  scale_fill_gradient2(name="Intensity",low = "blue", mid = "yellow", high =("red"), 
                       midpoint = 0.75, space = "rgb", na.value = "grey50", guide = "colourbar")+
  theme(legend.position=c(1,0),legend.justification=c(1,0),legend.title=element_text(size=20),legend.text=element_text(size=18),
        axis.text = element_text(size=20),axis.title = element_text(size=20),plot.title=element_text(size=20))+geom_point(alpha=0.1,size=1)





pdf(file = 'PDF/Figure6a.pdf',height=8,width=18)

Fig6a

dev.off()



pdf(file = 'PDF/Figure6b.pdf',height=8,width=8)

Fig6b

dev.off()


pdf(file = 'PDF/Figure6c.pdf',height=8,width=8)

Fig6c

dev.off()









