# Create figure 7 from
# Rothkegel, L. O. M., Trukenbrod, H. A., Schü̈tt, H. H., Wichmann, F. A., & Engbert, R. (2016).
# Influence of initial fixation position in scene viewing. Vision research, 129, 33–49. 


# Clear Workspace 
rm(list=ls())

# Set working directory to current source location

dir <- dirname(parent.frame(2)$ofile)
setwd(dir)

# Packages needed
library(spatstat)
library(ggplot2)
library(Rmisc)
library(gridExtra)



# Read Data and image boundaries



Table<-read.table("Fixations.dat",header=TRUE)
range <- read.table("Image_Range.dat",header=TRUE)
ImageType<-read.table("Image_Type.dat")


# Define Image Center
cx<-sum(range$xrange)/2
cy<-sum(range$yrange)/2


# Define Timepoints of new Fixations
TP<-c(0,Table$offsetR)
TP[which(is.na(TP))]<-0
TP<-TP[-length(TP)]


# Reduce table to important variables
table<-data.frame((Table$xR+Table$xL)/2,(Table$yR+Table$yL)/2,Table$image,Table$fd,Table$nth,Table$id,Table$type,Table$fCroX,TP)
rm(Table,TP)
colnames(table)<-c("xPos","yPos","Image","FixDur","Fixation_Number","Subject","type","Start","Time")

# Change Image Type from rater judgement to Post-Hoc Analysis of Saliency Maps and empirical saliency Map
table$type<-ImageType[table$Image,1]
rm(ImageType)
table$type[which(table$Image<33 & table$Image>16)]<-2


table<-table[order(table$Image),]


# Assign Factorized Starting Position
table$Start[which(table$Start<16)]<-1
table$Start[which(table$Start>16)]<-2


# Read in the ConfidenceIntervals as produced in Script Boot.R
Conf<-read.table("Confidence_Intervals.dat")


# Transform Fixation Data into mean eye position per milisecond

ttryx<-c()
Type<-c()
Start<-c()
X<-c()
for (p in unique(table$type)){
  for (f in 1:2){
    Tab<-table[which(table$Start==f & table$type==p),]
    Ttryx<-rep(0,10000)
    type<-rep(p,10000)
    start<-rep(f,10000)
    x<-1:10000
    a<-0
    for (l in unique(Tab$Subject)){
      for (j in 1:64){
        
        if(length(Tab$Time[which(Tab$Image==j & Tab$Subject==l)])>0){
          Tmod<-c(Tab$Time[which(Tab$Image==j & Tab$Subject==l)]+1,10000)
          Tx<-c(Tab$xPos[which(Tab$Image==j & Tab$Subject==l)])
          for(k in 1:(length(Tmod)-1)){
            Ttryx[Tmod[k]:Tmod[k+1]]<-Ttryx[Tmod[k]:Tmod[k+1]]+Tx[k]
          }
          a<-a+1
        }
      }}
    Ttryx<-Ttryx/a
    Type<-c(Type,type)
    Start<-c(Start,start)
    ttryx<-c(ttryx,Ttryx)
    X<-c(X,x)
  }}
tr<-data.frame(ttryx,Type,Start,X)
rm(ttryx,Type,Start,X)

tr$ttryx[which(tr$Start==1)]<-tr$ttryx[which(tr$Start==1)]-6.63
tr$ttryx[which(tr$Start==2)]<-26.52-tr$ttryx[which(tr$Start==2)]



# take mean eye position each ms and smooth with a gaussian smoothing of a sd of 100ms

sigma=100
Grate<-c()
Gratex<-c()
x<-c()
start<-c()
type<-c()
# Gaussian rate estimation 
t <- seq(from=0,to=9999,by=1)
L = length(t)
grate <- rep(0,L)
gratex <- rep(0,L)
for (i in unique(tr$Type)){
  for (j in 1:2){
    tabtype<-tr[which(tr$Start==j & tr$Type==i),]
    for ( w in 1:L ) {
      
      tau <- t - t[w] 
      
      grate[w] <- sum((1/(sqrt(2*pi)*sigma)*exp(-tau^2/(2*sigma^2)))*tabtype$ttry)
      gratex[w] <- sum((1/(sqrt(2*pi)*sigma)*exp(-tau^2/(2*sigma^2)))*tabtype$ttryx)
      #/sum((1/(sqrt(2*pi)*sigma)*exp(-tau^2/(2*sigma^2)))*tabtype$timelength)
      x<-c(x,w)
      start<-c(start,j)
      type<-c(type,i)
    }
    Grate<-c(Grate,grate)
    Gratex<-c(Gratex,gratex)
    print(i)}}

Data.Rate<-data.frame(x,Grate,Gratex,type,start)
rm(x,Grate,Gratex,type,start,tr)



# Start Ploting Figures. Define breaks for x and y axis

breakx<-seq(0,10000,2500)
breaky<-seq(0,1,0.2)
breakyx<-seq(0,30,3)


# Add Confidence Interval borders to dataframe Data.Rate

Data.Rate$Bootmax<-Conf$bootmax
Data.Rate$Bootmin<-Conf$bootmin
Data.Rate$BootType<-Conf$BootType
Data.Rate$BootStart<-Conf$BootStart
Data.Rate$sd<-Conf$sd
Data.Rate$upper<-Data.Rate$Gratex+Data.Rate$sd
Data.Rate$lower<-Data.Rate$Gratex-Data.Rate$sd


Data.Raeearly<-Data.Rate[which(Data.Rate$x<6001),]

Fig7a<-ggplot(Data.Raeearly,aes(x=x,y=Gratex,color=factor(type),linetype=factor(start)))+geom_path(size=1.5) + 
  ylab("Distance to Starting Position [°]") + ggtitle("") + 
  xlab("Time [ms]") +  scale_colour_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Balanced","2"="Pattern" ,"3"="Left Focus","4"="Right Focus")) +
  scale_linetype_manual("Start", values=c(1,3), labels=c("Left","Right")) + 
  scale_x_continuous(limits=c(0,6000),breaks=breakx) + scale_y_continuous(limits=c(0,18),breaks=breakyx) +
  theme(legend.position=c(1,0),legend.justification=c(1,0),axis.text=element_text(size=20),axis.title=element_text(size=20),
        legend.title=element_text(size=20),legend.text=element_text(size=20))+
  geom_hline(yintercept = 9.65,col="blue",linetype=4)





limits<-aes(ymax=Gratex+sd,ymin=Gratex-sd)

Fig7b<-ggplot(Data.Raeearly[which(Data.Raeearly$start==1),],aes(x=x,y=Gratex,color=factor(type),fill=factor(type)))+ geom_path()+ 
  geom_ribbon(limits,alpha=0.2) + 
  ylab("Distance") + ggtitle("") + xlab("Time [ms]") +  
  scale_colour_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Neutral","2"="Pattern" ,"3"="Leftsided","4"="Rightsided")) +
  scale_fill_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Neutral","2"="Pattern" ,"3"="Leftsided","4"="Rightsided")) +
  scale_x_continuous(limits=c(0,6000),breaks=breakx) + scale_y_continuous(limits=c(0,18),breaks=breakyx) +
  theme(legend.position=c(0.5,0),legend.justification=c(0.5,0),axis.text=element_text(size=20),
        axis.title=element_text(size=20),legend.title=element_text(size=20),legend.text=element_text(size=20))

Fig7b<-Fig7b + theme(legend.position="none",plot.title=element_text(size=25))  + geom_hline(yintercept = 9.65,col="blue",linetype=4)




Fig7c<-ggplot(Data.Raeearly[which(Data.Raeearly$start==2),],aes(x=x,y=Gratex,color=factor(type),fill=factor(type)))+ geom_path(linetype=3)+
  geom_ribbon(limits,alpha=0.2) + 
  ylab("Distance") + ggtitle("") + xlab("Time [ms]") + 
  scale_colour_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Neutral","2"="Pattern" ,"3"="Leftsided","4"="Rightsided")) +
  scale_fill_manual("Image Type", values = c(1,2,3,4),labels=c("1"="Neutral","2"="Pattern" ,"3"="Leftsided","4"="Rightsided")) +
  scale_x_continuous(limits=c(0,6000),breaks=breakx) + scale_y_continuous(limits=c(0,18),breaks=breakyx) +
  theme(legend.position=c(0.5,0),legend.justification=c(0.5,0),axis.text=element_text(size=20),
        axis.title=element_text(size=20),legend.title=element_text(size=20),legend.text=element_text(size=20))

Fig7c <- Fig7c + theme(legend.position="none",plot.title=element_text(size=25))  + geom_hline(yintercept = 9.65,col="blue",linetype=4)





pdf("PDF/Figure7.pdf",width=12,height=9)



Fig7=grid.arrange(Fig7a ,arrangeGrob(
  Fig7b ,
  Fig7c) ,ncol=2)


dev.off() 

